@@ -1,10 +1,10 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.084-7-gb371374
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.085-10-ge20fdbb
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 # vim: set ts=8 sw=4 tw=78 et :
-$Dist::Zilla::PluginBundle::Author::ETHER::VERSION = '0.085';
+our $VERSION = '0.086';
 use Moose;
 with
     'Dist::Zilla::Role::PluginBundle::Easy',
@@ -100,11 +100,14 @@ my %network_plugins;
 
 my $has_bash = can_run('bash');
 
+# files that might be in the repository that should never be gathered
+my @never_ship = qw(Makefile.PL README.md README.pod META.json cpanfile TODO);
+
 around BUILDARGS => sub
 {
     my $orig = shift;
     my $self = shift;
-    my ($args) = $self->$orig(@_);
+    my $args = $self->$orig(@_);
 
     # remove 'none' from installer list
     return $args if not exists $args->{payload}{installer};
@@ -130,7 +133,7 @@ sub configure
 
     my @plugins = (
         # VersionProvider
-        [ 'Git::NextVersion'    => { version_regexp => '^v([\d._]+)(-TRIAL)?$' } ],
+        [ 'RewriteVersion::Transitional' => { ':version' => '0.004', fallback_version_provider => 'Git::NextVersion', version_regexp => '^v([\d._]+)(-TRIAL)?$' } ],
 
         # BeforeBuild
         # [ 'EnsurePrereqsInstalled' ], # FIXME: use options to make this less annoying!
@@ -147,7 +150,7 @@ sub configure
 
         # Gather Files
         [ 'Git::GatherDir'      => { ':version' => '2.016', do {
-                my @filenames = grep { -e } uniq 'Makefile.PL', 'README.md', 'README.pod', 'META.json', 'cpanfile', $self->copy_files_from_release;
+                my @filenames = grep { -e } uniq @never_ship, $self->copy_files_from_release;
                 @filenames ? ( exclude_filename => \@filenames ) : ()
             },
         } ],
@@ -177,7 +180,7 @@ sub configure
 
         # Munge Files
         [ 'Git::Describe'       => { ':version' => '0.004', on_package_line => 1 } ],
-        [ PkgVersion            => { ':version' => '5.010', die_on_existing_version => 1, die_on_line_insertion => 1 } ],
+        # [RewriteVersion::Transitional], for the transitional usecase
         [
             ($self->surgical_podweaver ? 'SurgicalPodWeaver' : 'PodWeaver') => {
                 $self->surgical_podweaver ? () : ( ':version' => '4.005' ),
@@ -208,7 +211,7 @@ sub configure
         # (MakeMaker or other installer)
         'AutoPrereqs',
         'Prereqs::AuthorDeps',
-        [ 'MinimumPerl'         => { ':version' => '1.006' } ],
+        [ 'MinimumPerl'         => { ':version' => '1.006', configure_finder => ':NoFiles' } ],
         [ 'Prereqs' => pluginbundle_version => {
                 '-phase' => 'develop', '-relationship' => 'recommends',
                 $self->meta->name => $self->VERSION,
@@ -228,7 +231,7 @@ sub configure
         'CheckSelfDependency',
 
         ( $has_bash ?
-            [ 'Run::AfterBuild' => '.ackrc' => { run => q{bash -c "if [[ `dirname %d` != .build ]]; then test -e .ackrc && grep -q -- '--ignore-dir=%d' .ackrc || echo '--ignore-dir=%d' >> .ackrc; fi"} } ]
+            [ 'Run::AfterBuild' => '.ackrc' => { run => q{bash -c "test -e .ackrc && grep -q -- '--ignore-dir=.latest' .ackrc || echo '--ignore-dir=.latest' >> .ackrc; if [[ `dirname %d` != .build ]]; then test -e .ackrc && grep -q -- '--ignore-dir=%d' .ackrc || echo '--ignore-dir=%d' >> .ackrc; fi"} } ]
             : ()),
         [ 'Run::AfterBuild'     => '.latest' => { ':version' => '0.028', eval => q!if ('%d' =~ /^%n-[.[:xdigit:]]+$/) { unlink '.latest'; symlink '%d', '.latest'; }! } ],
 
@@ -256,6 +259,9 @@ sub configure
         [ 'Git::Commit'         => 'release snapshot' => { ':version' => '2.020', add_files_in => ['.'], allow_dirty => [ grep { -e } uniq 'Changes', 'README.md', 'README.pod', $self->copy_files_from_release ], commit_msg => '%N-%v%t%n%n%c' } ],
         [ 'Git::Tag'            => { tag_format => 'v%v%t', tag_message => 'v%v%t' } ],
         $self->server eq 'github' ? [ 'GitHub::Update' => { ':version' => '0.40', metacpan => 1 } ] : (),
+
+        [ 'BumpVersionAfterRelease::Transitional' => { ':version' => '0.004' } ],
+        [ 'Git::Commit'         => 'post-release commit' => { ':version' => '2.020', allow_dirty_match => '^lib/', commit_msg => 'increment $VERSION after release' } ],
         'Git::Push',
     );
 
@@ -285,7 +291,7 @@ sub configure
     }
 
     push @plugins, (
-        [ 'Run::AfterRelease'   => 'release complete' => { ':version' => '0.024', eval => [ qq{print "release complete!\n"} ] } ],
+        [ 'Run::AfterRelease'   => 'release complete' => { ':version' => '0.024', eval => [ qq{print "release complete!\\xa"} ] } ],
         # listed late, to allow all other plugins which do BeforeRelease checks to run first.
         'ConfirmRelease',
     );
@@ -356,7 +362,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.085
+version 0.086
 
 =head1 SYNOPSIS
 
@@ -370,7 +376,9 @@ This is a L<Dist::Zilla> plugin bundle. It is approximately equivalent to the
 following F<dist.ini> (following the preamble):
 
     ;;; VersionProvider
-    [Git::NextVersion]
+    [RewriteVersion::Transitional]
+    :version = 0.004
+    fallback_version_provider = Git::NextVersion
     version_regexp = ^v([\d._]+)(-TRIAL)?$
 
     ;;; BeforeBuild
@@ -457,11 +465,6 @@ following F<dist.ini> (following the preamble):
     :version = 0.004
     on_package_line = 1
 
-    [PkgVersion]
-    :version = 5.010
-    die_on_existing_version = 1
-    die_on_line_insertion = 1
-
     [PodWeaver] (or [SurgicalPodWeaver])
     :version = 4.005
     replacer = replace_with_comment
@@ -522,6 +525,7 @@ following F<dist.ini> (following the preamble):
     [Prereqs::AuthorDeps]
     [MinimumPerl]
     :version = 1.006
+    configure_finder = :NoFiles
 
     [Prereqs / installer_requirements]
     -phase = develop
@@ -549,7 +553,7 @@ following F<dist.ini> (following the preamble):
     [CheckSelfDependency]
 
     [Run::AfterBuild / .ackrc]
-    run = if [[ `dirname %d` != .build ]]; then test -e .ackrc && grep -q -- '--ignore-dir=%d' .ackrc || echo '--ignore-dir=%d' >> .ackrc; fi; if [[ %d =~ ^%n-[.[:xdigit:]]+$ ]]; then rm -f .latest; ln -s %d .latest; fi
+    run = bash -c "test -e .ackrc && grep -q -- '--ignore-dir=.latest' .ackrc || echo '--ignore-dir=.latest' >> .ackrc; if [[ `dirname %d` != .build ]]; then test -e .ackrc && grep -q -- '--ignore-dir=%d' .ackrc || echo '--ignore-dir=%d' >> .ackrc; fi; if [[ %d =~ ^%n-[.[:xdigit:]]+$ ]]; then rm -f .latest; ln -s %d .latest; fi"
     [Run::AfterBuild / .latest]
     :version = 0.028
     eval = if ('%d' =~ /^%n-[.[:xdigit:]]+$/) { unlink '.latest'; symlink '%d', '.latest'; }
@@ -613,6 +617,12 @@ following F<dist.ini> (following the preamble):
     :version = 0.40
     metacpan = 1
 
+    [BumpVersionAfterRelease::Transitional]
+    :version = 0.004
+    [Git::Commit / post-release commit]
+    :version = 2.020
+    allow_dirty_match = ^lib
+    commit_msg = increment $VERSION after release
     [Git::Push]
 
     [Run::AfterRelease / install release]
@@ -622,7 +632,7 @@ following F<dist.ini> (following the preamble):
 
     [Run::AfterRelease / release complete]
     :version = 0.024
-    eval = print "release complete!\n"
+    eval = print "release complete!\\xa"
 
     ; listed late, to allow all other plugins which do BeforeRelease checks to run first.
     [ConfirmRelease]
@@ -647,8 +657,7 @@ The version and other metadata is derived directly from the local git repository
 =head2 version
 
 Use C<< V=<version> >> in the shell to override the version of the distribution being built;
-otherwise the version is
-incremented from the last git tag.
+otherwise the version is incremented after each release, in the F<*.pm> files.
 
 =head2 pod coverage
 
