@@ -13,6 +13,12 @@ use JSON::MaybeXS;
 $ENV{USER} = 'notether';
 delete $ENV{DZIL_AIRPLANE};
 
+{
+    use Dist::Zilla::PluginBundle::Author::ETHER;
+    package Dist::Zilla::PluginBundle::Author::ETHER;
+    sub _pause_config { 'URMOM', 'mysekritpassword' }
+}
+
 # checks that all plugins in use are in the plugin bundle dist's runtime
 # requires list
 # - some plugins can be marked 'additional' - must be in recommended prereqs
@@ -63,7 +69,6 @@ sub all_plugins_in_prereqs
                 cmp_deeply(
                     $pluginbundle_meta->{prereqs}{runtime}{requires},
                     superhashof({ $plugin => $required_version }),
-
                     $plugin . ' is a runtime prereq of the plugin bundle',
                 ) or diag 'got plugin bundle metadata: ', explain $pluginbundle_meta;
             }
